@@ -79,6 +79,8 @@ brasero_burn_options_add_source (BraseroBurnOptions *self,
 
 	priv = BRASERO_BURN_OPTIONS_PRIVATE (self);
 
+	/* create message queue for input */
+	priv->message_input = brasero_notify_new ();
 	list = g_slist_prepend (list, priv->message_input);
 
 	va_start (vlist, title);
@@ -333,8 +335,8 @@ brasero_burn_options_valid_media_cb (BraseroSessionCfg *session,
 
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
 						      _("Would you like to burn beyond the disc reported capacity?"),
-						      _("The size of the project is too large for the disc."
-							"\nYou may want to use this option if you are using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
+						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
+							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
 							"\nNOTE: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
@@ -404,9 +406,6 @@ brasero_burn_options_init (BraseroBurnOptions *object)
 			    TRUE,
 			    0);
 
-	/* create message queue for input */
-	priv->message_input = brasero_notify_new ();
-
 	/* Medium selection box */
 	selection = gtk_hbox_new (FALSE, 12);
 	gtk_widget_show (selection);
