@@ -112,7 +112,7 @@ static GtkActionEntry entries [] = {
 	{"NewVideo", "media-optical-video-new", N_("New _Video Project"), NULL,
 	 N_("Create a video DVD or a SVCD that are readable on TV readers"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
 	{"NewCopy", "media-optical-copy", N_("Copy _Disc..."), NULL,
-	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hardisk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
+	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hard disk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
 	{"NewIso", "iso-image-burn", N_("_Burn Image..."), NULL,
 	 N_("Burn an existing CD/DVD image to disc"), G_CALLBACK (brasero_project_manager_new_iso_prj_cb)},
 
@@ -250,7 +250,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 		gchar *size_string;
 
 		if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
-			size_string = brasero_utils_get_time_string (files_size, TRUE, FALSE);
+			size_string = brasero_units_get_time_string (files_size, TRUE, FALSE);
 		else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA)
 			size_string = g_format_size_for_display (files_size);
 		else
@@ -265,7 +265,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 		gchar *size_string = NULL;
 
 		if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO) {
-			size_string = brasero_utils_get_time_string (files_size, TRUE, FALSE);
+			size_string = brasero_units_get_time_string (files_size, TRUE, FALSE);
 			status_string = g_strdup_printf (ngettext ("%d file is supported (%s)", "%d files are supported (%s)", valid_num),
 							 valid_num,
 							 size_string);
