@@ -97,20 +97,24 @@ brasero_session_cfg_get_gconf_key (BraseroSessionCfg *self,
 		return NULL;
 	
 	/* make sure display_name doesn't contain any forbidden characters */
-	display_name = brasero_drive_get_display_name (drive);
-	g_strdelimit (display_name, " +()", '_');
+	if (!brasero_drive_is_fake (drive)) {
+		gchar *tmp;
 
-	disc_type = g_strdup (brasero_medium_get_type_string (medium));
+		tmp = brasero_drive_get_display_name (drive);
+		display_name = gconf_escape_key (tmp, -1);
+		g_free (tmp);
+	}
+	else
+		display_name = g_strdup ("File");
+
+	display_name = display_name ? display_name : "";
+
+	disc_type = gconf_escape_key (brasero_medium_get_type_string (medium), -1);
 	if (!disc_type) {
 		g_free (display_name);
 		return NULL;
 	}
 
-	g_strdelimit (disc_type, " +()", '_');
-
-	display_name = display_name ? display_name : "";
-	disc_type = disc_type ? disc_type : "";
-
 	switch (brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (self), NULL)) {
 	case BRASERO_TRACK_TYPE_NONE:
 		key = g_strdup_printf ("%s/%s/none_%s/%s",
@@ -203,7 +207,7 @@ brasero_session_cfg_save_drive_properties (BraseroSessionCfg *self)
 		return;
 	}
 
-	gconf_client_set_int (client, key, rate / 1024, NULL);
+	gconf_client_set_int (client, key, rate / 1000, NULL);
 	g_free (key);
 
 	key = brasero_session_cfg_get_gconf_key (self, "flags");
@@ -231,19 +235,21 @@ static void
 brasero_session_cfg_add_drive_properties_flags (BraseroSessionCfg *self,
 						BraseroBurnFlag flags)
 {
+	BraseroMedia media;
 	BraseroBurnFlag flag;
 	BraseroBurnResult result;
 	BraseroSessionCfgPrivate *priv;
 
 	priv = BRASERO_SESSION_CFG_PRIVATE (self);
 
-	priv->supported = BRASERO_BURN_FLAG_NONE;
-	priv->compulsory = BRASERO_BURN_FLAG_NONE;
+	media = brasero_burn_session_get_dest_media (BRASERO_BURN_SESSION (self));
 
 	/* add flags then wipe out flags from session to check them one by one */
 	flags |= brasero_burn_session_get_flags (BRASERO_BURN_SESSION (self));
 	brasero_burn_session_remove_flag (BRASERO_BURN_SESSION (self), flags);
 
+	priv->supported = BRASERO_BURN_FLAG_NONE;
+	priv->compulsory = BRASERO_BURN_FLAG_NONE;
 	result = brasero_burn_caps_get_flags (priv->caps,
 					      BRASERO_BURN_SESSION (self),
 					      &priv->supported,
@@ -293,6 +299,24 @@ brasero_session_cfg_add_drive_properties_flags (BraseroSessionCfg *self,
 		}
 	}
 
+	if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_PLUS)
+	||  BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_RESTRICTED)
+	||  BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_PLUS_DL)) {
+		/* This is a special case to favour libburn/growisofs
+		 * wodim/cdrecord for these types of media. */
+		if (priv->supported & BRASERO_BURN_FLAG_MULTI) {
+			brasero_burn_session_add_flag (BRASERO_BURN_SESSION (self),
+						       BRASERO_BURN_FLAG_MULTI);
+
+			priv->supported = BRASERO_BURN_FLAG_NONE;
+			priv->compulsory = BRASERO_BURN_FLAG_NONE;
+			brasero_burn_caps_get_flags (priv->caps,
+						     BRASERO_BURN_SESSION (self),
+						     &priv->supported,
+						     &priv->compulsory);
+		}
+	}
+
 	/* Always set this flag whenever possible */
 	if (priv->supported & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
 		brasero_burn_session_add_flag (BRASERO_BURN_SESSION (self),
@@ -364,7 +388,7 @@ brasero_session_cfg_set_drive_properties (BraseroSessionCfg *self)
 	g_free (key);
 
 	if (value) {
-		rate = gconf_value_get_int (value) * 1024;
+		rate = gconf_value_get_int (value) * 1000;
 		gconf_value_free (value);
 	}
 	else
@@ -408,7 +432,7 @@ brasero_session_cfg_set_drive_properties (BraseroSessionCfg *self)
 			 BRASERO_BURN_FLAG_FAST_BLANK;
 	}
 	else if (!value) {
-		/* Set sound defaults */
+		/* Set sound defaults. */
 		flags = BRASERO_BURN_FLAG_EJECT|
 			BRASERO_BURN_FLAG_BURNPROOF;
 
