@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -25,8 +26,8 @@
 #include <glib.h>
 
 #include "burn-basics.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
 #include "burn-image-format.h"
 
 #ifndef _BURN_TRACK_H
@@ -49,11 +50,16 @@ typedef enum {
 	BRASERO_IMAGE_FS_UDF			= 1 << 1,
 	BRASERO_IMAGE_FS_JOLIET			= 1 << 2,
 	BRASERO_IMAGE_FS_VIDEO			= 1 << 3,
-	BRASERO_IMAGE_ISO_FS_LEVEL_3		= 1 << 4,
-	BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY	= 1 << 5,
+
+	/* The following one conflict with UDF and JOLIET */
+	BRASERO_IMAGE_FS_SYMLINK		= 1 << 4,
+
+	BRASERO_IMAGE_ISO_FS_LEVEL_3		= 1 << 5,
+	BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY	= 1 << 6,
 	BRASERO_IMAGE_FS_ANY			= BRASERO_IMAGE_FS_ISO|
 						  BRASERO_IMAGE_FS_UDF|
 						  BRASERO_IMAGE_FS_JOLIET|
+						  BRASERO_IMAGE_FS_SYMLINK|
 						  BRASERO_IMAGE_ISO_FS_LEVEL_3|
 						  BRASERO_IMAGE_FS_VIDEO|
 						  BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY
@@ -70,20 +76,23 @@ typedef enum {
 	BRASERO_AUDIO_FORMAT_48000		= 1 << 6,
 	BRASERO_VIDEO_FORMAT_UNDEFINED		= 1 << 7,
 	BRASERO_VIDEO_FORMAT_VCD		= 1 << 8,
-	BRASERO_VIDEO_FORMAT_VIDEO_DVD		= 1 << 9
+	BRASERO_VIDEO_FORMAT_VIDEO_DVD		= 1 << 9,
+
+	BRASERO_METADATA_INFO			= 1 << 10
 } BraseroAudioFormat;
 
 #define BRASERO_AUDIO_CAPS_AUDIO(caps_FORMAT)	((caps_FORMAT) & 0x007F)
-#define BRASERO_AUDIO_CAPS_VIDEO(caps_FORMAT)	((caps_FORMAT) & 0x0180)
+#define BRASERO_AUDIO_CAPS_VIDEO(caps_FORMAT)	((caps_FORMAT) & 0x0380)
 
 typedef enum {
 	BRASERO_CHECKSUM_NONE			= 0,
-	BRASERO_CHECKSUM_MD5			= 1,
-	BRASERO_CHECKSUM_MD5_FILE		= 1 << 1,
-	BRASERO_CHECKSUM_SHA1			= 1 << 2,
-	BRASERO_CHECKSUM_SHA1_FILE		= 1 << 3,
-	BRASERO_CHECKSUM_SHA256			= 1 << 4,
-	BRASERO_CHECKSUM_SHA256_FILE		= 1 << 5
+	BRASERO_CHECKSUM_DETECT			= 1,		/* means the plugin handles detection of checksum type */
+	BRASERO_CHECKSUM_MD5			= 1 << 1,
+	BRASERO_CHECKSUM_MD5_FILE		= 1 << 2,
+	BRASERO_CHECKSUM_SHA1			= 1 << 3,
+	BRASERO_CHECKSUM_SHA1_FILE		= 1 << 4,
+	BRASERO_CHECKSUM_SHA256			= 1 << 5,
+	BRASERO_CHECKSUM_SHA256_FILE		= 1 << 6,
 } BraseroChecksumType;
 
 #define	BRASERO_MIN_AUDIO_TRACK_LENGTH		((gint64) 6 * 1000000000)
@@ -145,6 +154,10 @@ struct _BraseroTrackType {
 };
 typedef struct _BraseroTrackType BraseroTrackType;
 
+BraseroBurnResult
+brasero_track_type_is_supported (BraseroTrackType *type);
+
+
 #define BRASERO_TRACK_TYPE_HAS_VIDEO(type_MACRO)				\
 	(((type_MACRO)->type == BRASERO_TRACK_TYPE_AUDIO) &&			\
 	 ((type_MACRO)->subtype.audio_format & (BRASERO_VIDEO_FORMAT_UNDEFINED|	\
@@ -252,6 +265,7 @@ brasero_track_get_data_excluded_source (BraseroTrack *track,
 
 BraseroBurnResult
 brasero_track_get_data_paths (BraseroTrack *track,
+			      gboolean use_joliet,
 			      const gchar *grafts_path,
 			      const gchar *excluded_path,
 			      const gchar *emptydir,
@@ -327,8 +341,14 @@ brasero_track_tag_lookup (BraseroTrack *track,
  * Commonly used Tags
  */
 
-#define BRASERO_TRACK_MEDIUM_ADDRESS_START_TAG	"track::medium::address::start"
-#define BRASERO_TRACK_MEDIUM_ADDRESS_END_TAG	"track::medium::address::end"
+#define BRASERO_TRACK_MEDIUM_ADDRESS_START_TAG		"track::medium::address::start"
+#define BRASERO_TRACK_MEDIUM_ADDRESS_END_TAG		"track::medium::address::end"
+
+/**
+ * Array of filenames (on medium) which have a wrong checksum value (G_TYPE_STRV)
+ */
+
+#define BRASERO_TRACK_MEDIUM_WRONG_CHECKSUM_TAG		"track::medium::error::checksum::list"
 
 G_END_DECLS
 
