@@ -357,7 +357,7 @@ brasero_dvd_author_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* NOTE: it seems that cdrecord can burn cue files on the fly */
 	brasero_plugin_define (plugin,
 			       "dvdauthor",
-			       _("use dvdauthor to convert a set of files to burn to Video DVDs"),
+			       _("Use dvdauthor to create Video DVDs"),
 			       "Philippe Rouquier",
 			       1);
 
@@ -372,11 +372,24 @@ brasero_dvd_author_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_AUDIO_FORMAT_RAW|
 					BRASERO_AUDIO_FORMAT_44100|
 					BRASERO_AUDIO_FORMAT_48000|
+					BRASERO_METADATA_INFO|
 					BRASERO_VIDEO_FORMAT_VIDEO_DVD);
+
 	output = brasero_caps_data_new (BRASERO_IMAGE_FS_ISO|
 					BRASERO_IMAGE_FS_UDF|
 					BRASERO_IMAGE_FS_VIDEO);
 
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (input);
+
+	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					BRASERO_AUDIO_FORMAT_AC3|
+					BRASERO_AUDIO_FORMAT_MP2|
+					BRASERO_AUDIO_FORMAT_RAW|
+					BRASERO_AUDIO_FORMAT_44100|
+					BRASERO_AUDIO_FORMAT_48000|
+					BRASERO_VIDEO_FORMAT_VIDEO_DVD);
+
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 	g_slist_free (input);
@@ -386,7 +399,7 @@ brasero_dvd_author_export_caps (BraseroPlugin *plugin, gchar **error)
   				  BRASERO_MEDIUM_FILE|
 				  BRASERO_MEDIUM_DVDR|
 				  BRASERO_MEDIUM_DVDR_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_DUAL_L|
 				  BRASERO_MEDIUM_BLANK|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -397,7 +410,7 @@ brasero_dvd_author_export_caps (BraseroPlugin *plugin, gchar **error)
 				  BRASERO_MEDIUM_DVDRW|
 				  BRASERO_MEDIUM_DVDRW_PLUS|
 				  BRASERO_MEDIUM_DVDRW_RESTRICTED|
-				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_DUAL_L|
 				  BRASERO_MEDIUM_BLANK|
 				  BRASERO_MEDIUM_CLOSED|
 				  BRASERO_MEDIUM_APPENDABLE|
