@@ -778,23 +778,30 @@ brasero_local_track_start_thread (BraseroLocalTrack *self,
 				  GError **error)
 {
 	BraseroLocalTrackPrivate *priv;
+	GError *thread_error = NULL;
 
 	priv = BRASERO_LOCAL_TRACK_PRIVATE (self);
 
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
+	priv->cancel = g_cancellable_new ();
+
 	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_local_track_thread,
 					self,
 					TRUE,
-					error);
+					&thread_error);
 	g_mutex_unlock (priv->mutex);
 
-	if (!priv->thread) 
+	/* Reminder: this is not necessarily an error as the thread may have finished */
+	//if (!priv->thread)
+	//	return BRASERO_BURN_ERR;
+	if (thread_error) {
+		g_propagate_error (error, thread_error);
 		return BRASERO_BURN_ERR;
+	}
 
-	priv->cancel = g_cancellable_new ();
 	return BRASERO_BURN_OK;
 }
 
@@ -1141,5 +1148,7 @@ brasero_local_track_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_process_flags (plugin, BRASERO_PLUGIN_RUN_PREPROCESSING);
 
+	brasero_plugin_set_compulsory (plugin, FALSE);
+
 	return BRASERO_BURN_OK;
 }
